@@ -144,6 +144,8 @@ class IpeConverter:
                 points = [(x1,y1), (x2,y2)]
                 edge = Line(points)
             
+            if 'Opacity' in data:
+                edge.stroke_opacity = data['Opacity']
             
             if 'Stroke' in data:
                 edge.stroke = data['Stroke']
